You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by ch...@apache.org on 2013/11/18 16:27:52 UTC

git commit: Fixing som e typos.

Updated Branches:
  refs/heads/trunk 511b60c6f -> de5838660


Fixing som e typos.


Project: http://git-wip-us.apache.org/repos/asf/activemq/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq/commit/de583866
Tree: http://git-wip-us.apache.org/repos/asf/activemq/tree/de583866
Diff: http://git-wip-us.apache.org/repos/asf/activemq/diff/de583866

Branch: refs/heads/trunk
Commit: de58386607f6c080ae5466a17d5c9cdbd25b8df8
Parents: 511b60c
Author: Hiram Chirino <hi...@hiramchirino.com>
Authored: Mon Nov 18 10:23:36 2013 -0500
Committer: Hiram Chirino <hi...@hiramchirino.com>
Committed: Mon Nov 18 10:24:00 2013 -0500

----------------------------------------------------------------------
 .../org/apache/activemq/ra/ActiveMQManagedConnection.java | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq/blob/de583866/activemq-ra/src/main/java/org/apache/activemq/ra/ActiveMQManagedConnection.java
----------------------------------------------------------------------
diff --git a/activemq-ra/src/main/java/org/apache/activemq/ra/ActiveMQManagedConnection.java b/activemq-ra/src/main/java/org/apache/activemq/ra/ActiveMQManagedConnection.java
index 571fbf3..f8caf09 100755
--- a/activemq-ra/src/main/java/org/apache/activemq/ra/ActiveMQManagedConnection.java
+++ b/activemq-ra/src/main/java/org/apache/activemq/ra/ActiveMQManagedConnection.java
@@ -196,7 +196,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
      * @see javax.resource.spi.ManagedConnection#destroy()
      */
     public void destroy() throws ResourceException {
-        // Have we allready been destroyed??
+        // Have we already been destroyed??
         if (isDestroyed()) {
             return;
         }
@@ -207,7 +207,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
             physicalConnection.close();
             destroyed = true;
         } catch (JMSException e) {
-            LOG.info("Error occured during close of a JMS connection.", e);
+            LOG.info("Error occurred during close of a JMS connection.", e);
         }
     }
 
@@ -219,7 +219,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
      */
     public void cleanup() throws ResourceException {
 
-        // Have we allready been destroyed??
+        // Have we already been destroyed??
         if (isDestroyed()) {
             return;
         }
@@ -368,7 +368,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
     }
 
     /**
-     * When a proxy is closed this cleans up the proxy and notifys the
+     * When a proxy is closed this cleans up the proxy and notifies the
      * ConnectionEventListeners that a connection closed.
      * 
      * @param proxy
@@ -386,7 +386,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
         for (ManagedConnectionProxy proxy:proxyConnections) {
             proxy.onException(e);
         }
         // Let the container know that the error occured.
         fireErrorOccurredEvent(e);
     }
@@ -386,7 +386,7 @@ public class ActiveMQManagedConnection implements ManagedConnection, ExceptionLi
             proxy.onException(e);
         }
-        // Let the container know that the error occured.
+        // Let the container know that the error occurred.
         fireErrorOccurredEvent(e);
     }